summaryrefslogtreecommitdiffstats
path: root/src/bdd/cudd/cuddInt.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/bdd/cudd/cuddInt.h')
-rw-r--r--src/bdd/cudd/cuddInt.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/bdd/cudd/cuddInt.h b/src/bdd/cudd/cuddInt.h
index a5d0cf16..df843e33 100644
--- a/src/bdd/cudd/cuddInt.h
+++ b/src/bdd/cudd/cuddInt.h
@@ -346,7 +346,7 @@ struct DdManager { /* specialized DD symbol table */
long *linear; /* linear transform matrix */
/* Memory Management */
DdNode **memoryList; /* memory manager for symbol table */
- DdNode *nextFree; /* list of free nodes */
+ DdNode *nextFree; /* list of ABC_FREE nodes */
char *stash; /* memory reserve */
#ifndef DD_NO_DEATH_ROW
DdNode **deathRow; /* queue for dereferencing */
@@ -410,7 +410,7 @@ struct DdManager { /* specialized DD symbol table */
double cacheLastInserts; /* insertions at the last cache resizing */
double cachedeletions; /* number of deletions during garbage coll. */
#ifdef DD_STATS
- double nodesFreed; /* number of nodes returned to the free list */
+ double nodesFreed; /* number of nodes returned to the ABC_FREE list */
double nodesDropped; /* number of nodes killed by dereferencing */
#endif
unsigned int peakLiveNodes; /* maximum number of live nodes */
@@ -481,10 +481,10 @@ typedef struct DdLevelQueue {
/**Macro***********************************************************************
- Synopsis [Adds node to the head of the free list.]
+ Synopsis [Adds node to the head of the ABC_FREE list.]
- Description [Adds node to the head of the free list. Does not
- deallocate memory chunks that become free. This function is also
+ Description [Adds node to the head of the ABC_FREE list. Does not
+ deallocate memory chunks that become ABC_FREE. This function is also
used by the dynamic reordering functions.]
SideEffects [None]